@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
 
 package Tangence::Object;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 
@@ -59,49 +59,18 @@ sub new
 
       event_subs => {},   # {$event} => [ @cbs ]
 
-      properties => {}, # {$prop} => [ $value, \@callbacks ]
+      properties => {}, # {$prop} => T:P::Instance struct
    }, $class;
 
    my $properties = $self->class->properties;
    foreach my $prop ( keys %$properties ) {
-      $self->_new_property( $prop, $properties->{$prop} );
+      my $meth = "new_prop_$prop";
+      $self->$meth();
    }
 
    return $self;
 }
 
-sub _new_property
-{
-   my $self = shift;
-   my ( $prop, $pdef ) = @_;
-
-   my $dim = $pdef->dimension;
-
-   my $initial;
-
-   if( my $code = $self->can( "init_prop_$prop" ) ) {
-      $initial = $code->( $self );
-   }
-
-   elsif( $dim == DIM_SCALAR ) {
-      $initial = $pdef->type->default_value;
-   }
-   elsif( $dim == DIM_HASH ) {
-      $initial = {};
-   }
-   elsif( $dim == DIM_QUEUE or $dim == DIM_ARRAY ) {
-      $initial = [];
-   }
-   elsif( $dim == DIM_OBJSET ) {
-      $initial = {}; # these have hashes internally
-   }
-   else {
-      croak "Unrecognised dimension $dim for property $prop";
-   }
-
-   $self->{properties}->{$prop} = [ $initial, [] ];
-}
-
 =head1 METHODS
 
 =cut
@@ -409,11 +378,11 @@ sub watch_property
       }
    }
 
-   my $watchlist = $self->{properties}->{$prop}->[1];
+   my $watchlist = $self->{properties}->{$prop}->callbacks;
 
    push @$watchlist, $callbacks;
 
-   $on_updated->( $self, $self->{properties}->{$prop}->[0] ) if $on_updated;
+   $on_updated->( $self, $self->{properties}->{$prop}->value ) if $on_updated;
 
    my $ref = \@{$watchlist}[$#$watchlist];  # reference to last element
    return $ref + 0; # force numeric context
@@ -431,7 +400,7 @@ sub unwatch_property
    my $self = shift;
    my ( $prop, $id ) = @_;
 
-   my $watchlist = $self->{properties}->{$prop}->[1] or return;
+   my $watchlist = $self->{properties}->{$prop}->callbacks or return;
 
    my $index;
    for( $index = 0; $index < @$watchlist; $index++ ) {
