@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2016 -- leonerd@leonerd.org.uk
 
 package Tangence::ObjectProxy;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 
@@ -657,18 +657,18 @@ sub _watch_property
    });
 }
 
-=head2 watch_property_with_iter
+=head2 watch_property_with_cursor
 
-   ( $iter, $first_idx, $last_idx ) =
-      $proxy->watch_property_with_iter( $property, $iter_from, %callbacks )->get
+   ( $cursor, $first_idx, $last_idx ) =
+      $proxy->watch_property_with_cursor( $property, $from, %callbacks )->get
 
 A variant of C<watch_property> that installs a watch on the given property of
-the server object, and additionally returns an iterator object that can be
-used to lazily fetch the values stored in it.
+the server object, and additionally returns an cursor object that can be used
+to lazily fetch the values stored in it.
 
-The C<$iter_from> value indicates which end of the queue the iterator should
-start from; C<ITER_FIRST> to start at index 0, or C<ITER_LAST> to start at the
-highest-numbered index. The iterator is created atomically with installing the
+The C<$from> value indicates which end of the queue the cursor should start
+from; C<CUSR_FIRST> to start at index 0, or C<CUSR_LAST> to start at the
+highest-numbered index. The cursor is created atomically with installing the
 watch.
 
 =cut
@@ -676,20 +676,27 @@ watch.
 sub watch_property_with_iter
 {
    my $self = shift;
-   my ( $property, $iter_from, %args ) = @_;
 
    # Detect void-context legacy uses
    defined wantarray or
       croak "->watch_property_with_iter in void context no longer useful - it now returns a Future";
 
-   if( $iter_from eq "first" ) {
-      $iter_from = ITER_FIRST;
+   return $self->watch_property_with_cursor( @_ );
+}
+
+sub watch_property_with_cursor
+{
+   my $self = shift;
+   my ( $property, $from, %args ) = @_;
+
+   if( $from eq "first" ) {
+      $from = CUSR_FIRST;
    }
-   elsif( $iter_from eq "last" ) {
-      $iter_from = ITER_LAST;
+   elsif( $from eq "last" ) {
+      $from = CUSR_LAST;
    }
    else {
-      croak "Unrecognised 'iter_from' value %s";
+      croak "Unrecognised 'from' value $from";
    }
 
    my $pdef = $self->can_property( $property )
@@ -701,35 +708,35 @@ sub watch_property_with_iter
    my $smashed = $pdef->smashed;
 
    if( my $cbs = $self->{props}->{$property}->{cbs} ) {
-      die "TODO: need to synthesize a second iterator";
+      die "TODO: need to synthesize a second cursor";
    }
 
    $self->{props}->{$property}->{cbs} = [ $callbacks ];
 
    if( $smashed ) {
-      die "TODO: need to synthesize an iterator";
+      die "TODO: need to synthesize an cursor";
    }
 
    my $client = $self->{client};
-   $client->_ver_can_iter or croak "Server is too old to support MSG_WATCH_ITER";
+   $client->_ver_can_cursor or croak "Server is too old to support MSG_WATCH_CUSR";
    $pdef->dimension == DIM_QUEUE or croak "Can only iterate on queue-dimension properties";
 
    $client->request(
-      request => Tangence::Message->new( $client, MSG_WATCH_ITER )
+      request => Tangence::Message->new( $client, MSG_WATCH_CUSR )
          ->pack_int( $self->id )
          ->pack_str( $property )
-         ->pack_int( $iter_from ),
+         ->pack_int( $from ),
    )->then( sub {
       my ( $message ) = @_;
       my $code = $message->code;
 
-      if( $code == MSG_WATCHING_ITER ) {
-         my $iter_id = $message->unpack_int();
+      if( $code == MSG_WATCHING_CUSR ) {
+         my $cursor_id = $message->unpack_int();
          my $first_idx = $message->unpack_int();
          my $last_idx  = $message->unpack_int();
 
-         my $iter = Tangence::ObjectProxy::_PropertyIterator->new( $self, $iter_id, $pdef->type );
-         Future->done( $iter, $first_idx, $last_idx );
+         my $cursor = Tangence::ObjectProxy::_Cursor->new( $self, $cursor_id, $pdef->type );
+         Future->done( $cursor, $first_idx, $last_idx );
       }
       else {
          Future->fail( "Unexpected response code $code", tangence => );
@@ -920,7 +927,7 @@ sub unwatch_property
    $self->can_property( $property )
       or croak "Class ".$self->classname." does not have a property $property";
 
-   # TODO: mark iterators as destroyed and invalid
+   # TODO: mark cursors as destroyed and invalid
    delete $self->{props}->{$property};
 
    my $client = $self->{client};
@@ -934,14 +941,14 @@ sub unwatch_property
 }
 
 package # hide from index
-   Tangence::ObjectProxy::_PropertyIterator;
+   Tangence::ObjectProxy::_Cursor;
 use Carp;
 use Tangence::Constants;
 
-=head1 ITERATOR METHODS
+=head1 CURSOR METHODS
 
-The following methods are availilable on the property iterator objects given
-to the C<on_iter> callback of a C<watch_property> method.
+The following methods are availilable on the property cursor objects returned
+by the C<watch_property_with_cursor> method.
 
 =cut
 
@@ -962,7 +969,7 @@ sub DESTROY
    return unless $self->obj and my $id = $self->id and my $client = $self->client;
 
    $client->request(
-      request => Tangence::Message->new( $client, MSG_ITER_DESTROY )
+      request => Tangence::Message->new( $client, MSG_CUSR_DESTROY )
          ->pack_int( $id ),
 
       on_response => sub {},
@@ -971,13 +978,13 @@ sub DESTROY
 
 =head2 next_forward
 
-   ( $index, @more ) = $iter->next_forward( $count )->get
+   ( $index, @more ) = $cursor->next_forward( $count )->get
 
 =head2 next_backward
 
-   ( $index, @more ) = $iter->next_backward( $count )->get
+   ( $index, @more ) = $cursor->next_backward( $count )->get
 
-Requests the next items from the iterator. C<next_forward> moves forwards
+Requests the next items from the cursor. C<next_forward> moves forwards
 towards higher-numbered indices, and C<next_backward> moves backwards towards
 lower-numbered indices. If C<$count> is unspecified, a default of 1 will
 apply.
@@ -985,20 +992,20 @@ apply.
 The returned future wil yield the index of the first element returned, and the
 new elements. Note that there may be fewer elements returned than were
 requested, if the end of the queue was reached. Specifically, there will be no
-new elements if the iterator is already at the end.
+new elements if the cursor is already at the end.
 
 =cut
 
 sub next_forward
 {
    my $self = shift;
-   $self->_next( ITER_FWD, @_ );
+   $self->_next( CUSR_FWD, @_ );
 }
 
 sub next_backward
 {
    my $self = shift;
-   $self->_next( ITER_BACK, @_ );
+   $self->_next( CUSR_BACK, @_ );
 }
 
 sub _next
@@ -1017,7 +1024,7 @@ sub _next
    my $client = $self->client;
 
    $client->request(
-      request => Tangence::Message->new( $client, MSG_ITER_NEXT )
+      request => Tangence::Message->new( $client, MSG_CUSR_NEXT )
          ->pack_int( $id )
          ->pack_int( $direction )
          ->pack_int( $count || 1 ),
@@ -1025,7 +1032,7 @@ sub _next
       my ( $message ) = @_;
       my $code = $message->code;
 
-      if( $code == MSG_ITER_RESULT ) {
+      if( $code == MSG_CUSR_RESULT ) {
          Future->done(
             $message->unpack_int(),
             $message->unpack_all_sametype( $element_type ),
