@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2016 -- leonerd@leonerd.org.uk
 
 package Tangence::Server;
 
@@ -10,7 +10,7 @@ use warnings;
 
 use base qw( Tangence::Stream );
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 
@@ -20,6 +20,9 @@ use Tangence::Constants;
 use Tangence::Types;
 use Tangence::Server::Context;
 
+use Struct::Dumb;
+struct CursorObject => [qw( cursor obj )];
+
 # We will accept any version back to 2
 use constant VERSION_MINOR_MIN => 2;
 
@@ -134,6 +137,12 @@ sub tangence_closed
 
       undef @$watches;
    }
+
+   if( my $cursors = $self->peer_hascursor ) {
+      foreach my $cursorobj ( values %$cursors ) {
+         $self->drop_cursorobj( $cursorobj );
+      }
+   }
 }
 
 sub get_by_id
@@ -278,7 +287,7 @@ sub handle_request_SETPROP
 }
 
 *handle_request_WATCH      = \&_handle_request_WATCHany;
-*handle_request_WATCH_ITER = \&_handle_request_WATCHany;
+*handle_request_WATCH_CUSR = \&_handle_request_WATCHany;
 sub _handle_request_WATCHany
 {
    my $self = shift;
@@ -287,12 +296,12 @@ sub _handle_request_WATCHany
    my $objid = $message->unpack_int();
    my $prop  = $message->unpack_str();
    my $want_initial;
-   my $iter_from;
+   my $from;
    if( $message->code == MSG_WATCH ) {
       $want_initial = $message->unpack_bool();
    }
-   elsif( $message->code == MSG_WATCH_ITER ) {
-      $iter_from = $message->unpack_int();
+   elsif( $message->code == MSG_WATCH_CUSR ) {
+      $from = $message->unpack_int();
    }
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
@@ -309,12 +318,12 @@ sub _handle_request_WATCHany
       $ctx->respond( Tangence::Message->new( $self, MSG_WATCHING ) );
       $self->_send_initial( $object, $prop ) if $want_initial;
    }
-   elsif( $message->code == MSG_WATCH_ITER ) {
-      my $m = "iter_prop_$prop";
-      my $iter = $object->$m( $iter_from );
-      my $id = $self->message_state->{next_iterid}++;
-      $self->peer_hasiter->{$id} = $iter;
-      $ctx->respond( Tangence::Message->new( $self, MSG_WATCHING_ITER )
+   elsif( $message->code == MSG_WATCH_CUSR ) {
+      my $m = "cursor_prop_$prop";
+      my $cursor = $object->$m( $from );
+      my $id = $self->message_state->{next_cursorid}++;
+      $self->peer_hascursor->{$id} = CursorObject( $cursor, $object );
+      $ctx->respond( Tangence::Message->new( $self, MSG_WATCHING_CUSR )
          ->pack_int( $id )
          ->pack_int( 0 ) # first index
          ->pack_int( $#{ $object->${\"get_prop_$prop"} } ) # last index
@@ -369,35 +378,45 @@ sub handle_request_UNWATCH
    $ctx->respond( Tangence::Message->new( $self, MSG_OK ) );
 }
 
-sub handle_request_ITER_NEXT
+sub handle_request_CUSR_NEXT
 {
    my $self = shift;
    my ( $token, $message ) = @_;
 
-   my $iterid = $message->unpack_int();
+   my $cursor_id = $message->unpack_int();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   my $iter = $self->peer_hasiter->{$iterid} or
-      return $ctx->responderr( "No such iterator with id $iterid" );
+   my $cursorobj = $self->peer_hascursor->{$cursor_id} or
+      return $ctx->responderr( "No such cursor with id $cursor_id" );
 
-   $iter->handle_request_ITER_NEXT( $ctx, $message );
+   $cursorobj->cursor->handle_request_CUSR_NEXT( $ctx, $message );
 }
 
-sub handle_request_ITER_DESTROY
+sub handle_request_CUSR_DESTROY
 {
    my $self = shift;
    my ( $token, $message ) = @_;
 
-   my $iterid = $message->unpack_int();
+   my $cursor_id = $message->unpack_int();
 
    my $ctx = Tangence::Server::Context->new( $self, $token );
 
-   delete $self->peer_hasiter->{$iterid};
+   my $cursorobj = delete $self->peer_hascursor->{$cursor_id};
+   $self->drop_cursorobj( $cursorobj );
 
    $ctx->respond( Tangence::Message->new( $self, MSG_OK ) );
 }
 
+sub drop_cursorobj
+{
+   my $self = shift;
+   my ( $cursorobj ) = @_;
+
+   my $m = "uncursor_prop_" . $cursorobj->cursor->prop->name;
+   $cursorobj->obj->$m( $cursorobj->cursor );
+}
+
 sub handle_request_INIT
 {
    my $self = shift;
